import{s as a,c as s,a as e,C as t}from"./chunk-B4BG7PRW-S4u-CDhd.js";import{_ as i}from"./Mermaid-y0Vi1B4-.js";import"./chunk-FMBD7UC4-CdHR02dn.js";import"./chunk-55IACEB6-Ds_X7EmJ.js";import"./chunk-QN33PNHL-BhwfinzR.js";import"./index-D7sItsLN.js";import"./_commonjsHelpers-CqkleIqs.js";import"./purify.es-HRjpPm7y.js";var f={parser:e,get db(){return new t},renderer:s,styles:a,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{f as diagram};
